Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3715)

Unified Diff: chrome/browser/cocoa/delayedmenu_button_unittest.mm

Issue 251091: Mac: Eliminate unintended "menu" method overrides. (Closed)
Patch Set: Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/cocoa/delayedmenu_button.mm ('k') | chrome/browser/cocoa/menu_button.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/cocoa/delayedmenu_button_unittest.mm
diff --git a/chrome/browser/cocoa/delayedmenu_button_unittest.mm b/chrome/browser/cocoa/delayedmenu_button_unittest.mm
index b04cb27c7dedf62805218127477b5aaf863579c2..a9eaa7f01043d0b85b6817d9552c411a5b17f284 100644
--- a/chrome/browser/cocoa/delayedmenu_button_unittest.mm
+++ b/chrome/browser/cocoa/delayedmenu_button_unittest.mm
@@ -52,16 +52,17 @@ TEST_F(DelayedMenuButtonTest, MenuAssign) {
[menu insertItemWithTitle:@"bar" action:nil keyEquivalent:@"" atIndex:2];
[menu insertItemWithTitle:@"baz" action:nil keyEquivalent:@"" atIndex:3];
- [button_ setMenu:menu];
- EXPECT_TRUE([button_ menu]);
+ [button_ setAttachedMenu:menu];
+ EXPECT_TRUE([button_ attachedMenu]);
- [button_ setMenuEnabled:YES];
- EXPECT_TRUE([button_ menuEnabled]);
+ [button_ setAttachedMenuEnabled:YES];
+ EXPECT_TRUE([button_ attachedMenuEnabled]);
// TODO(viettrungluu): Display the menu. (Calling DelayedMenuButton's private
// |-menuAction:| method displays it fine, but the problem is getting rid of
// the menu. We can catch the |NSMenuDidBeginTrackingNotification| from |menu|
// fine, but then |-cancelTracking| doesn't dismiss it. I don't know why.)
}
// TODO(viettrungluu): Test the two actions of the button (the normal one and
« no previous file with comments | « chrome/browser/cocoa/delayedmenu_button.mm ('k') | chrome/browser/cocoa/menu_button.h » ('j') | no next file with comments »
@@ -52,16 +52,17 @@ TEST_F(DelayedMenuButtonTest, MenuAssign) {
// TODO(viettrungluu): Display the menu. (Calling DelayedMenuButton's private
- // |-menuAction:| method displays it fine, but the problem is getting rid of
- // the menu. We can catch the |NSMenuDidBeginTrackingNotification| from |menu|
- // fine, but then |-cancelTracking| doesn't dismiss it. I don't know why.)
+ // |-attachedMenuAction:| method displays it fine, but the problem is
+ // getting rid of the menu. We can catch the
+ // |NSMenuDidBeginTrackingNotification| from |menu| fine, but then
+ // |-cancelTracking| doesn't dismiss it. I don't know why.)
}
// TODO(viettrungluu): Test the two actions of the button (the normal one and

Powered by Google App Engine
This is Rietveld 408576698